# arat rapid annotation tool (arat) #

## Documentation ##

In an attempt to keep all user-facing documentation in one place, please visit
the [arat homepage][arat] which contains extensive documentation and examples
of how to use and configure arat. We apologise for only providing minimal
documentation along with the installation package but the risk of having
out-dated documentation delivered to our end-users is unacceptable.

If you find bugs in your arat installation or errors in the documentation,
please file an issue at our [issue tracker][arat_issues] and we will strive to
address it promptly.

[arat_issues]:  https://github.com/neophnx/arat/issues

## About arat ##

*arat* (arat rapid annotation tool) is a fork of brat (brat rapid annotation tool)
wich goal is to provide a reliable and modern tool to assist any text annotation task.

A modern tool because it works out of the box in many python2.7 or python3 environment
with the same code base.

It is reliable because extensive test sets are included with the code, something that brat lacks.

## License ##

arat itself is available under the permissive [MIT License][mit] but
incorporates software using a variety of open-source licenses, for details
please see see LICENSE.md.

[mit]:  http://opensource.org/licenses/MIT

## Contributing ##

As with any software arat is under continuous development. If you have
requests for features please [file an issue][arat_issues] describing your
request. Also, if you want to see work towards a specific feature feel free to
contribute by working towards it. The standard procedure is to fork the
repository, add a feature, fix a bug, then file a pull request that your
changes are to be merged into the main repository and included in the next
release. If you seek guidance or pointers please notify the arat developers
and we will be more than happy to help.

If you send a pull request you agree that the code will be distributed under
the same license as arat (MIT). Additionally, all non-anonymous contributors
are recognised in the CONTRIBUTORS.md file.

